powered by
Visualizations for mlr3filters::Filter. The argument type controls what kind of plot is drawn. Possible choices are:
type
"barplot" (default): Bar plot of filter scores.
"barplot"
# S3 method for Filter autoplot(object, type = "boxplot", n = Inf, theme = theme_minimal(), ...)
ggplot2::ggplot().
ggplot2::ggplot()
(mlr3filters::Filter).
(character(1)): Type of the plot. See description.
(integer(1)) Only include the first n features with the highest importance. Defaults to all features.
integer(1)
n
(ggplot2::theme()) The ggplot2::theme_minimal() is applied by default to all plots.
ggplot2::theme()
ggplot2::theme_minimal()
(ignored).
if (mlr3misc::require_namespaces("mlr3filters", quietly = TRUE)) { library(mlr3filters) task = tsk("mtcars") f = flt("correlation") f$calculate(task) head(fortify(f)) autoplot(f, n = 5) }
Run the code above in your browser using DataLab