powered by
Visualizations for mlr3::LearnerClassif. The argument type controls what kind of plot is drawn. Possible choices are:
type
"prediction" (default): Decision boundary of the learner and the true class labels.
"prediction"
# S3 method for LearnerClassif autoplot( object, type = "prediction", task, grid_points = 100L, expand_range = 0, theme = theme_minimal(), ... )
ggplot2::ggplot().
ggplot2::ggplot()
(mlr3::LearnerClassif).
(character(1)): Type of the plot. See description.
(mlr3::Task) Train task.
(integer(1)) Number of grid points per feature dimension.
(numeric(1)) Expand the range of the grid.
(ggplot2::theme()) The ggplot2::theme_minimal() is applied by default to all plots.
ggplot2::theme()
ggplot2::theme_minimal()
(ignored).
# \donttest{ task = tsk("pima")$select(c("age", "pedigree")) learner = lrn("classif.rpart", predict_type = "prob") learner$train(task) autoplot(learner, type = "prediction", task) # }
Run the code above in your browser using DataLab