Learn R Programming

mlr3viz (version 0.5.8)

autoplot.PredictionClust: Plot for PredictionClust

Description

Generates plots for mlr3cluster::PredictionClust, depending on argument type:

  • "scatter" (default): scatterplot with correlation values and colored cluster assignments.

  • "sil": Silhouette plot with mean silhouette value as a reference line. Requires package ggfortify.

  • "pca": Perform PCA on data and color code cluster assignments. Inspired by and uses ggfortify::autoplot.kmeans.

Usage

# S3 method for PredictionClust
autoplot(object, task, row_ids = NULL, type = "scatter", ...)

Arguments

row_ids

row ids to subset task data to ensure that only the data used to make predictions are shown in plots.

type

(character(1)): Type of the plot. See description.

...

(any): Additional arguments, passed down to the respective geom.

Value

ggplot2::ggplot() object.

Theme

The theme_mlr3() and viridis color maps are applied by default to all autoplot() methods. To change this behavior set options(mlr3.theme = FALSE).

References

Tang Y, Horikoshi M, Li W (2016). “ggfortify: Unified Interface to Visualize Statistical Result of Popular R Packages.” The R Journal, 8(2), 474--485. 10.32614/RJ-2016-060.

Examples

Run this code
# NOT RUN {
library(mlr3)
library(mlr3cluster)
library(mlr3viz)

task = tsk("usarrests")
learner = lrn("clust.kmeans", centers = 3)
object = learner$train(task)$predict(task)

head(fortify(object))
autoplot(object, task)
# }

Run the code above in your browser using DataLab