Learn R Programming

mlr3viz (version 0.5.8)

autoplot.TaskRegr: Plot for Regression Tasks

Description

Generates plots for mlr3::TaskRegr, depending on argument type:

  • "target": Box plot of target variable (default).

  • "pairs": Passes data and additional arguments down to GGally::ggpairs(). Color is set to target column.

Usage

# S3 method for TaskRegr
autoplot(object, type = "target", ...)

Arguments

type

(character(1)): Type of the plot. See description.

...

(any): Additional argument, passed down to the underlying geom or plot functions.

Value

ggplot2::ggplot() object.

Theme

The theme_mlr3() and viridis color maps are applied by default to all autoplot() methods. To change this behavior set options(mlr3.theme = FALSE).

Examples

Run this code
# NOT RUN {
library(mlr3)
library(mlr3viz)

task = tsk("mtcars")
task$select(c("am", "carb"))

head(fortify(task))
autoplot(task)
autoplot(task, type = "pairs")
# }

Run the code above in your browser using DataLab