Learn R Programming

mlr3viz (version 0.5.8)

autoplot.TaskSurv: Plot for Survival Tasks

Description

Generates plots for mlr3proba::TaskSurv, depending on argument type:

Usage

# S3 method for TaskSurv
autoplot(object, type = "target", ...)

Arguments

type

(character(1)): Type of the plot. Available choices:

...

(any): Additional arguments. rhs is passed down to $formula of mlr3proba::TaskSurv for stratification for type "target". Other arguments are passed to the respective underlying plot functions.

Value

ggplot2::ggplot() object.

Theme

The theme_mlr3() and viridis color maps are applied by default to all autoplot() methods. To change this behavior set options(mlr3.theme = FALSE).

Examples

Run this code
# NOT RUN {
library(mlr3)
library(mlr3viz)
library(mlr3proba)

task = tsk("lung")

head(fortify(task))
autoplot(task)
autoplot(task, rhs = "sex")
autoplot(task, type = "duo")
# }

Run the code above in your browser using DataLab