powered by
Generates plots for mlr3cluster::TaskClust, depending on argument type:
type
"pairs": Passes data and additional arguments down to GGally::ggpairs() (default).
"pairs"
GGally::ggpairs()
# S3 method for TaskClust autoplot(object, type = "pairs", ...)
(mlr3cluster::TaskClust).
(character(1)): Type of the plot. See description.
(any): Additional argument, passed down to the underlying geom or plot functions.
any
geom
ggplot2::ggplot() object.
ggplot2::ggplot()
The theme_mlr3() and viridis color maps are applied by default to all autoplot() methods. To change this behavior set options(mlr3.theme = FALSE).
theme_mlr3()
autoplot()
options(mlr3.theme = FALSE)
# NOT RUN { library(mlr3) library(mlr3cluster) library(mlr3viz) task = mlr_tasks$get("usarrests") head(fortify(task)) autoplot(task) # }
Run the code above in your browser using DataLab