powered by
Generates plots for mlr3::TaskRegr, depending on argument type:
type
"target": Box plot of target variable (default).
"target"
"pairs": Passes data and additional arguments down to GGally::ggpairs(). Color is set to target column.
"pairs"
GGally::ggpairs()
# S3 method for TaskRegr autoplot(object, type = "target", ...)
(mlr3::TaskRegr).
(character(1)): Type of the plot. See description.
(any): Additional argument, passed down to the underlying geom or plot functions.
any
geom
ggplot2::ggplot() object.
ggplot2::ggplot()
The theme_mlr3() and viridis color maps are applied by default to all autoplot() methods. To change this behavior set options(mlr3.theme = FALSE).
theme_mlr3()
autoplot()
options(mlr3.theme = FALSE)
# NOT RUN { library(mlr3) library(mlr3viz) task = tsk("mtcars") task$select(c("am", "carb")) head(fortify(task)) autoplot(task) autoplot(task, type = "pairs") # }
Run the code above in your browser using DataLab